# EC-Master-Python

The Python Wrapper provides a Python interface to use EC-Master, EC-Simulator and RAS Client/Server.

For more information please refer the user manual:
https://public.acontis.com/manuals/EC-Master/3.1/html/ec-master-python/index.html

The binaries are not included into the package. 

Please contact our support to request an EVAL version:
https://www.acontis.com/ 
